decodeText method

  1. @override
String decodeText(
  1. String part,
  2. Encoding codec, {
  3. bool isHeader = false,
})
override

Decodes the given part text with the given codec.

isHeader is set to the true when this text originates from a header

Implementation

@override
String decodeText(String part, Encoding codec, {bool isHeader = false}) {
  final outputList = decodeData(part);

  return codec.decode(outputList);
}