decodeText abstract method

String decodeText(
  1. String part,
  2. Encoding codec, {
  3. bool isHeader = false,
})

Decodes the given part text with the given codec.

isHeader is set to the true when this text originates from a header

Implementation

String decodeText(
  String part,
  convert.Encoding codec, {
  bool isHeader = false,
});