addDomain method
Adds the domain with the name to the list of associated domains
Implementation
void addDomain(String name) {
domains ??= <String>[];
domains?.add(name);
}
Adds the domain with the name to the list of associated domains
void addDomain(String name) {
domains ??= <String>[];
domains?.add(name);
}