isSecureSocket property
bool
get
isSecureSocket
Retrieves true when this server uses a secure connection
Implementation
bool get isSecureSocket => socketType == SocketType.ssl;
Retrieves true when this server uses a secure connection
bool get isSecureSocket => socketType == SocketType.ssl;