attributes property

Map<String, dynamic> attributes
final

Further attributes

Note that you need to specify these attributes in case you want them, by default an unmodifiable const {} is used.

Implementation

final Map<String, dynamic> attributes;