deleteMessage method
Deletes the given message.
Depending on the service capabilities either the message is moved to the trash, copied to the trash or just flagged as deleted.
Optionally set expunge to true to clear the messages directly from
disk on IMAP servers. In that case, the delete operation cannot be undone.
Returns a DeleteResult that can be used for an undo operation, compare undoDeleteMessages.
The UID of the message will be updated automatically.
Implementation
Future<DeleteResult> deleteMessage(
MimeMessage message, {
bool expunge = false,
}) =>
deleteMessages(MessageSequence.fromMessage(message), expunge: expunge);