fetchMessagePart method
Future<MimePart>
fetchMessagePart(
- MimeMessage message,
- String fetchId, {
- Duration? responseTimeout,
Fetches the part with the specified fetchId of the specified message.
This can be useful when you have specified an automatic download
limit with downloadSizeLimit in the MailClient's constructor and want
to download an individual attachment, for example.
Note that this is only possible when the user is connected via IMAP and
not via POP.
Compare lowLevelIncomingMailClientType.
Implementation
Future<MimePart> fetchMessagePart(
MimeMessage message,
String fetchId, {
Duration? responseTimeout,
}) =>
_incomingLock.synchronized(
() => _incomingMailClient.fetchMessagePart(
message,
fetchId,
responseTimeout: responseTimeout,
),
);