undoDeleteMessages method
Reverts the previous deleteResult
Note that is only possible when deleteResult.canUndo is true.
The UIDs of the associated messages will be updated automatically, when the messages have been specified in the original delete operation.
Compare deleteMessages
Implementation
Future<DeleteResult> undoDeleteMessages(DeleteResult deleteResult) =>
_incomingLock.synchronized(
() => _incomingMailClient.undoDeleteMessages(deleteResult),
);