isManualSynchronizationRequired property
Is true when the server does not support quick resync (QRSYNC)
or a similar method.
Implementation
final bool isManualSynchronizationRequired;
Is true when the server does not support quick resync (QRSYNC)
or a similar method.
final bool isManualSynchronizationRequired;