Tree<T> constructor
Tree<T> (
- T rootValue
Creates a new tree with the given root value
Implementation
Tree(T rootValue) : root = TreeElement(rootValue, null);
Creates a new tree with the given root value
Tree(T rootValue) : root = TreeElement(rootValue, null);