fetchMessages method
Future<FetchImapResult>
fetchMessages(
- MessageSequence sequence,
- String? fetchContentDefinition, {
- int? changedSinceModSequence,
- Duration? responseTimeout,
Fetches messages by the given definition.
sequence the sequence IDs of the messages that should be fetched
fetchContentDefinition the definition of what should be fetched from
the message, e.g. (UID ENVELOPE HEADER[]), BODY[] or ENVELOPE, etc
Specify the changedSinceModSequence in case only messages that have
been changed since the specified modification sequence should be fetched.
Note that this requires the CONDSTORE or QRESYNC server capability.
Specify a responseTimeout when a response is expected within the
given time.
Implementation
Future<FetchImapResult> fetchMessages(
MessageSequence sequence,
String? fetchContentDefinition, {
int? changedSinceModSequence,
Duration? responseTimeout,
}) =>
_fetchMessages(
false,
'FETCH',
sequence,
fetchContentDefinition,
changedSinceModSequence: changedSinceModSequence,
responseTimeout: responseTimeout,
);