selectInbox method
Selects the inbox.
This allows future search and fetch calls.
Set enableCondStore to true if you want to force-enable CONDSTORE.
This is only possible when the CONDSTORE or
QRESYNC capability is supported.
Specify qresync parameter in case the server supports the QRESYNC
capability and you have known values from the last session.
Note that you need to ENABLE QRESYNC first.
Compare enable
Implementation
Future<Mailbox> selectInbox({
bool enableCondStore = false,
QResyncParameters? qresync,
}) =>
selectMailboxByPath(
'INBOX',
enableCondStore: enableCondStore,
qresync: qresync,
);