selectMailbox method
Future<Mailbox>
selectMailbox(
- Mailbox box, {
- bool enableCondStore = false,
- QResyncParameters? qresync,
Selects the specified mailbox.
This allows future search and fetch calls.
box the mailbox that should be selected.
Set enableCondStore to true if you want to force-enable CONDSTORE.
This is only possible when the CONDSTORE or QRESYNC capability
is supported.
Specify qresync parameter in case the server supports the QRESYNC
capability and you have known values from the last session.
Note that you need to ENABLE QRESYNC first.
Compare enable
Implementation
Future<Mailbox> selectMailbox(
Mailbox box, {
bool enableCondStore = false,
QResyncParameters? qresync,
}) =>
_selectOrExamine(
'SELECT',
box,
enableCondStore: enableCondStore,
qresync: qresync,
);