uidCopy method
Future<GenericImapResult>
uidCopy(
- MessageSequence sequence, {
- Mailbox? targetMailbox,
- String? targetMailboxPath,
Copies the specified message(s) from the specified sequence
from the currently selected mailbox to the target mailbox.
You can either specify the targetMailbox or the targetMailboxPath,
if none is given, the messages will be copied to the currently
selected mailbox.
Compare selectMailbox, selectMailboxByPath or selectInbox for
selecting a mailbox first.
Compare copy for the version with message sequence IDs
Implementation
Future<GenericImapResult> uidCopy(
MessageSequence sequence, {
Mailbox? targetMailbox,
String? targetMailboxPath,
}) =>
_copyOrMove(
'UID COPY',
sequence,
targetMailbox: targetMailbox,
targetMailboxPath: targetMailboxPath,
);