uidFetchMessages method
Future<FetchImapResult>
uidFetchMessages(
- MessageSequence sequence,
- String? fetchContentDefinition, {
- int? changedSinceModSequence,
- Duration? responseTimeout,
Fetches messages by the given definition.
sequence the sequence of message UIDs for which messages should
be fetched
fetchContentDefinition the definition of what should be fetched from
the message, e.g. 'BODY[]' or 'ENVELOPE', etc
Specify the changedSinceModSequence in case only messages that have
been changed since the specified modification sequence should be fetched.
Note that this requires the CONDSTORE or QRESYNC server capability.
Specify a responseTimeout when you expect a response within a the
specified duration.
Also compare uidFetchMessagesByCriteria.
Implementation
Future<FetchImapResult> uidFetchMessages(
MessageSequence sequence,
String? fetchContentDefinition, {
int? changedSinceModSequence,
Duration? responseTimeout,
}) =>
_fetchMessages(
true,
'UID FETCH',
sequence,
fetchContentDefinition,
changedSinceModSequence: changedSinceModSequence,
responseTimeout: responseTimeout,
);