uidMarkAnswered method
Future<StoreImapResult>
uidMarkAnswered(
- MessageSequence sequence, {
- bool? silent,
- int? unchangedSinceModSequence,
Mark the messages from the specified sequence as answered.
Set silent to true in case the updated flags are of no interest.
Specify the unchangedSinceModSequence to limit the store action to
elements that have not changed since the specified modification sequence.
This is only supported when the server supports the
CONDSTORE or QRESYNC capability
Compare the uidStore method in case you need more control or want to
change several flags.
Implementation
Future<StoreImapResult> uidMarkAnswered(
MessageSequence sequence, {
bool? silent,
int? unchangedSinceModSequence,
}) =>
uidStore(
sequence,
[MessageFlags.answered],
silent: silent,
unchangedSinceModSequence: unchangedSinceModSequence,
);