uidMove method
Future<GenericImapResult>
uidMove(
- MessageSequence sequence, {
- Mailbox? targetMailbox,
- String? targetMailboxPath,
Copies the specified message(s) from the specified sequence
from the currently selected mailbox to the target mailbox.
You must either specify the targetMailbox or the targetMailboxPath,
if none is given, move will fail.
Compare selectMailbox, selectMailboxByPath or selectInbox for
selecting a mailbox first.
Compare copy for the version with message sequence IDs
Implementation
Future<GenericImapResult> uidMove(
MessageSequence sequence, {
Mailbox? targetMailbox,
String? targetMailboxPath,
}) {
if (targetMailbox == null && targetMailboxPath == null) {
throw InvalidArgumentException('uidMove() error: Neither targetMailbox '
'nor targetMailboxPath defined.');
}
return _copyOrMove(
'UID MOVE',
sequence,
targetMailbox: targetMailbox,
targetMailboxPath: targetMailboxPath,
);
}