uidStore method
- MessageSequence sequence,
- List<
String> flags, { - StoreAction? action,
- bool? silent,
- int? unchangedSinceModSequence,
Updates the flags of the message(s) from the specified sequence
in the currently selected mailbox.
Set silent to true, if the updated flags should not be returned.
Specify if flags should be replaced, added or removed with the action
parameter, this defaults to adding flags.
Specify the unchangedSinceModSequence to limit the store action to
elements that have not changed since the specified modification sequence.
This is only supported when the server supports the CONDSTORE or
QRESYNC capability
When there are modified elements that have not passed the
unchangedSinceModSequence test, then the modifiedMessageSequence
field of the contains the sequence of messages that have NOT been
updated by this store command.
Compare selectMailbox, selectMailboxByPath or selectInbox for
selecting a mailbox first.
Compare the methods uidMarkSeen, uidMarkFlagged, etc for typical
store operations.
Implementation
Future<StoreImapResult> uidStore(
MessageSequence sequence,
List<String> flags, {
StoreAction? action,
bool? silent,
int? unchangedSinceModSequence,
}) =>
_store(
true,
'UID STORE',
sequence,
flags,
action: action,
silent: silent,
unchangedSinceModSequence: unchangedSinceModSequence,
);