MessageSequence.fromAll constructor
MessageSequence.fromAll()
Convenience method for getting the sequence for all messages.
Implementation
MessageSequence.fromAll() : isUidSequence = false {
addAll();
}
Convenience method for getting the sequence for all messages.
MessageSequence.fromAll() : isUidSequence = false {
addAll();
}