PagedMessageSequence class

A paginated list of message IDs

Constructors

PagedMessageSequence(MessageSequence sequence, {int pageSize = 30})
Creates a new paged sequence from the given sequence with the optional pageSize.
PagedMessageSequence.empty({int pageSize = 30})
Creates a new empty paged sequence with the optional pageSize.

Properties

currentPageIndex → int
Retrieves the 0-based index of the current page
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool
Checks if this paged list has a next page
no setter
isUidSequence → bool
Determines if this is a UID sequence
no setter
length → int
Retrieves the length of the sequence
no setter
pageSize → int
The page size
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → MessageSequence
The original sequence
final

Methods

add(int id) → void
Adds the given id to this paged sequence
getCurrentPage() → MessageSequence
Retrieves the sequence for the current page.
getSequence(int pageIndex) → MessageSequence
Retrieves the sequence for the specified page index
insert(int id) → void
Inserts the given id to this paged sequence
next() → MessageSequence
Advances this sequence to the next page and then returns getCurrentPage().
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageIndexOf(int index) → int
Retrieves the page index for the given ID
remove(int id) → void
Removes the given id from this paged sequence
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → int
Retrieves the ID at the given index