isFailedStatus property
bool
get
isFailedStatus
Returns true when the response status is not ok
Implementation
bool get isFailedStatus => !isOkStatus;
Returns true when the response status is not ok
bool get isFailedStatus => !isOkStatus;