highestModSequence property
The highest modification sequence in the searched messages
The modification sequence can only be returned when the MODSEQ search
criteria has been used and when the server supports the
CONDSTORE capability.
Implementation
int? highestModSequence;