isMultipart property
bool
get
isMultipart
Is the associated message part a multipart ie contains further parts?
Implementation
bool get isMultipart => mediaType?.top == MediaToptype.multipart;
Is the associated message part a multipart ie contains further parts?
bool get isMultipart => mediaType?.top == MediaToptype.multipart;