isOther property
bool
get
isOther
Is the associated message part of unknown media type?
Implementation
bool get isOther => mediaType?.top == MediaToptype.other;
Is the associated message part of unknown media type?
bool get isOther => mediaType?.top == MediaToptype.other;