size property
int?
get
size
The size of the associated message part in bytes
Implementation
int? get size => contentDisposition?.size;
The size of the associated message part in bytes
int? get size => contentDisposition?.size;