hasAttachments method
Checks if this message has parts with a Content-Disposition: attachment
header.
Implementation
bool hasAttachments() => hasContent(ContentDisposition.attachment);
Checks if this message has parts with a Content-Disposition: attachment
header.
bool hasAttachments() => hasContent(ContentDisposition.attachment);