hasContent method
Checks if this message has parts with the specified disposition.
Note that either the full message or the body structure must have been downloaded before.
Implementation
bool hasContent(ContentDisposition disposition) =>
findContentInfo(disposition: disposition).isNotEmpty;