getHeaderValue method
Retrieves the raw value of the first matching header.
Some headers may contain encoded values such as '=?utf-8?B?
Compare decodeHeaderValue for retrieving the header value in decoded form.
Compare getHeader for retrieving the full header with the given name.
Implementation
String? getHeaderValue(String name) =>
_getLowerCaseHeaderValue(name.toLowerCase());