insertPart method
Inserts the part at the beginning of all parts.
Implementation
void insertPart(MimePart part) {
parts ??= <MimePart>[];
parts?.insert(0, part);
}
Inserts the part at the beginning of all parts.
void insertPart(MimePart part) {
parts ??= <MimePart>[];
parts?.insert(0, part);
}