renderField method
Renders the field with the given name and value to the buffer.
Set quote to true to quote the value.
When the value is null, nothing will be rendered.
Implementation
void renderField(
String name,
String? value,
StringBuffer buffer, {
bool quote = false,
}) {
if (value == null) {
return;
}
buffer
..write('; ')
..write(name)
..write('=');
if (quote) {
buffer.write('"');
}
buffer.write(value);
if (quote) {
buffer.write('"');
}
}