value property
The value without parameters as specified in the header,
eg text/plain for a Content-Type header.
Implementation
late String value;
The value without parameters as specified in the header,
eg text/plain for a Content-Type header.
late String value;