uidList method

Future<List<MessageListing>> uidList([
  1. int? messageId
])

Checks the ID and UID of all messages or of the message with the specified messageId

This command is optional and may not be supported by all servers.

Implementation

Future<List<MessageListing>> uidList([int? messageId]) =>
    sendCommand(PopUidListCommand(messageId));