defaultReadReceiptTemplate constant
String
const defaultReadReceiptTemplate
Standard template for message disposition notification messages aka read receipts.
When you want to use your own template you can use the fields
<subject>, <date>, <recipient> and <sender>.
Implementation
static const String defaultReadReceiptTemplate =
'''The message sent on <date> to <recipient> with '
'subject "<subject>" has been displayed.\r
This is no guarantee that the message has been read or understood.''';