encodedWordMaxLength constant

int const encodedWordMaxLength

The maximum length of an encoded word in header space should not be longer than 75 characters.

That includes the charset, encoding, delimiters and actual data, compare https://tools.ietf.org/html/rfc2047#section-2

Implementation

static const int encodedWordMaxLength = 75;