MediaSubtype enum
Detailed media types Compare https://www.iana.org/assignments/media-types/media-types.xhtml
- Inheritance
- Available extensions
Values
- textPlain → const MediaSubtype
-
text/plainjust plain/normal text - textHtml → const MediaSubtype
-
text/htmltext in HTML format - textCalendar → const MediaSubtype
-
text/calendarorx-vcalendarhttps://www.iana.org/go/rfc5545as an attachment you can also use MediaSubtype.applicationIcs
- textVcard → const MediaSubtype
-
text/vcardhttps://www.iana.org/go/rfc6350 - textMarkdown → const MediaSubtype
-
text/markdownhttps://www.iana.org/go/rfc7763 - textRfc822Headers → const MediaSubtype
-
text/rfc822-headersHeaders of an email message - audioBasic → const MediaSubtype
-
audio/basicbasic audio - audioMpeg → const MediaSubtype
-
audio/mpegmpeg audio - audioMp3 → const MediaSubtype
-
audio/mp3mp3 audio - audioMp4 → const MediaSubtype
-
audio/mp4mp4 audio - audioOgg → const MediaSubtype
-
audio/oggogg audio - audioWav → const MediaSubtype
-
audio/wavwav audio - audioMidi → const MediaSubtype
-
audio/midimidi audio - audioMod → const MediaSubtype
-
audio/modmod audio - audioAiff → const MediaSubtype
-
audio/aiffaiff audio - audioWebm → const MediaSubtype
-
audio/webmwebm audio - audioAac → const MediaSubtype
-
audio/aacaac audio - imageJpeg → const MediaSubtype
-
image/jpegjpeg/jpg image - imagePng → const MediaSubtype
-
image/pngpng image - imageGif → const MediaSubtype
-
image/gifgif image - imageWebp → const MediaSubtype
-
image/webpwebp image - imageBmp → const MediaSubtype
-
image/bmpbmp image - imageSvgXml → const MediaSubtype
-
image/svg+xmlsvg image in xml format - videoMpeg → const MediaSubtype
-
video/mpegmpeg video - videoMp4 → const MediaSubtype
-
video/mp4mp4 video - videoWebm → const MediaSubtype
-
video/webmwebm video - videoH264 → const MediaSubtype
-
video/h264h264 video - videoOgg → const MediaSubtype
-
video/oggogg video - applicationJson → const MediaSubtype
-
application/jsonjson data - applicationZip → const MediaSubtype
-
application/zipcompressed file - applicationXml → const MediaSubtype
-
application/xmlxml data - applicationOctetStream → const MediaSubtype
-
application/octet-streambinary data - applicationCalendarJson → const MediaSubtype
-
application/calendar+jsoncalendar data https://www.iana.org/go/rfc7265 - applicationCalendarXml → const MediaSubtype
-
application/calendar+xmlcalendar data https://www.iana.org/go/rfc6321 - applicationVcardJson → const MediaSubtype
-
application/vcard+jsoncontact data - applicationVcardXml → const MediaSubtype
-
application/vcard+xmlcontact data - applicationPdf → const MediaSubtype
-
application/pdfhttps://www.iana.org/go/rfc8118 - applicationIcs → const MediaSubtype
-
application/icsiCalendar attachmentWithin an alternative multipart you need to use MediaSubtype.textCalendar instead
- applicationOfficeDocumentWordProcessingDocument → const MediaSubtype
-
application/vnd.openxmlformats-officedocument.wordprocessingml.document - applicationOfficeDocumentWordProcessingTemplate → const MediaSubtype
-
application/vnd.openxmlformats-officedocument.wordprocessingml.template - applicationOfficeDocumentSpreadsheetSheet → const MediaSubtype
-
application/vnd.openxmlformats-officedocument.spreadsheetml.sheet - applicationOfficeDocumentSpreadsheetTemplate → const MediaSubtype
-
application/vnd.openxmlformats-officedocument.spreadsheetml.template - applicationOfficeDocumentPresentationPresentation → const MediaSubtype
-
application/vnd.openxmlformats-officedocument.presentationml.presentation - applicationOfficeDocumentPresentationTemplate → const MediaSubtype
-
application/vnd.openxmlformats-officedocument.presentationml.template - applicationPgpSignature → const MediaSubtype
-
application/pgp-signaturepart that contains the signature - applicationPgpEncrypted → const MediaSubtype
-
application/pgp-encryptedencrypted message part - applicationPgpKeys → const MediaSubtype
-
applicationPgpKeyspart that contains PGP keys - modelMesh → const MediaSubtype
-
model/mesh3D model - modelVrml → const MediaSubtype
-
model/vrml3D model - modelX3dXml → const MediaSubtype
-
model/x3d+xml3D model - modelX3dVrml → const MediaSubtype
-
model/x3d+vrmlormodel/x3d-vrml3D model - modelX3dBinary → const MediaSubtype
-
model/x3d+binaryormodel/x3d+fastinfoset3D model - modelVndColladaXml → const MediaSubtype
-
model/vnd.collada+xml3D model - messageRfc822 → const MediaSubtype
-
message/rfc822embedded message,https://tools.ietf.org/html/rfc2045 https://tools.ietf.org/html/rfc2046
- messagePartial → const MediaSubtype
-
message/partialpartial message,https://tools.ietf.org/html/rfc2045 https://tools.ietf.org/html/rfc2046
- messageDeliveryStatus → const MediaSubtype
-
delivery status of a message,
- messageDispositionNotification → const MediaSubtype
-
read receipt,
- multipartAlternative → const MediaSubtype
-
multipart/alternativeshow on of the embedded parts - multipartMixed → const MediaSubtype
-
multipart/mixedshow all embedded parts in the given sequence - multipartParallel → const MediaSubtype
-
multipart/parallelshow all embedded parts at once - multipartPartial → const MediaSubtype
-
multipart/partialcontains a single part of a bigger complete part. - multipartRelated → const MediaSubtype
-
multipart/relatedcontains parts that belong logically together - multipartDigest → const MediaSubtype
-
multipart/digestcontains several rcf822 messages - multipartSigned → const MediaSubtype
-
multipart/signedsigned message - multipartEncrypted → const MediaSubtype
-
multipart/encryptedencrypted message - multipartReport → const MediaSubtype
-
multipart/reportReport - fontOtf → const MediaSubtype
-
font/otfotf font - fontTtf → const MediaSubtype
-
font/ttfttf font - fontWoff → const MediaSubtype
-
font/woffwoff font - fontWoff2 → const MediaSubtype
-
font/woff2woff2 font - fontCollection → const MediaSubtype
-
font/collectioncollection of several fonts - other → const MediaSubtype
-
other media sub type
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mediaType → MediaType
-
Available on MediaSubtype, provided by the MediaSubtypeExtension extension
Retrieves a new media type based on this subtypeno setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MediaSubtype> - A constant List of the values in this enum, in order of their declaration.