MessageBuilder constructor

MessageBuilder({
  1. String? text,
  2. TransferEncoding transferEncoding = TransferEncoding.automatic,
  3. CharacterSet? characterSet,
  4. ContentTypeHeader? contentType,
  5. HeaderEncoding subjectEncoding = HeaderEncoding.Q,
})

Creates a new message builder and populates it with the optional data.

Set the plain text part with text encoded with transferEncoding using the given characterSet.

You can also set the complete contentType. Finally you can set the subjectEncoding, defaulting to quoted printable.

Implementation

MessageBuilder({
  String? text,
  TransferEncoding transferEncoding = TransferEncoding.automatic,
  CharacterSet? characterSet,
  ContentTypeHeader? contentType,
  this.subjectEncoding = HeaderEncoding.Q,
}) : super(
        MimeMessage(),
        text: text,
        transferEncoding: transferEncoding,
        characterSet: characterSet,
        contentType: contentType,
      ) {
  _message = _part as MimeMessage;
}