keywordMdnSent constant

String const keywordMdnSent

For this message a read notification has been sent

  • note this is a common but not standardized keyword.

Implementation

static const String keywordMdnSent = r'$MDNSent';