recent constant
String
const recent
Marks this message as being recent.
This flag cannot be changed or set by clients.
Implementation
static const String recent = r'\Recent';
Marks this message as being recent.
This flag cannot be changed or set by clients.
static const String recent = r'\Recent';