contentDisposition property
The way that this part should be handled, e.g. inline or as attachment.
Implementation
ContentDispositionHeader? contentDisposition;
The way that this part should be handled, e.g. inline or as attachment.
ContentDispositionHeader? contentDisposition;