getTextHtmlPart method
Retrieves the first builder with a text/plain part.
Note that only this builder and direct children are queried.
Implementation
PartBuilder? getTextHtmlPart() => getPart(MediaSubtype.textHtml);
Retrieves the first builder with a text/plain part.
Note that only this builder and direct children are queried.
PartBuilder? getTextHtmlPart() => getPart(MediaSubtype.textHtml);