setHeader method
Sets a header with the specified name and value
This replaces any previous header with the same name.
Compare MailConventions for common header names.
Set encoding to any of the HeaderEncoding formats to
encode the header.
Implementation
void setHeader(
String name,
String? value, {
HeaderEncoding encoding = HeaderEncoding.none,
}) {
_part.setHeader(name, value, encoding);
}