sendChunkedMessageText method
Future<SmtpResponse>
sendChunkedMessageText(
- String text,
- MailAddress from,
- List<
MailAddress> recipients, { - required bool supportUnicode,
- bool use8BitEncoding = false,
Sends the specified message text from to the recipients
using the BDAT SMTP command.
BDATA is supported when the SMTP server announces the CHUNKING
capability in its EHLO response.
You can query SmtpServerInfo.supportsChunking for this.
In contrast to the other methods the text is not modified apart from the
padding of <CR><LF>.<CR><LF> sequences.
Set use8BitEncoding to true for sending a UTF-8 encoded message body.
Implementation
Future<SmtpResponse> sendChunkedMessageText(
String text,
MailAddress from,
List<MailAddress> recipients, {
required bool supportUnicode,
bool use8BitEncoding = false,
}) {
if (recipients.isEmpty) {
throw SmtpException(this, SmtpResponse(['500 no recipients']));
}
return sendCommand(
SmtpSendBdatMailTextCommand(
text,
from,
recipients.map((r) => r.email).toList(),
supportUnicode: supportUnicode,
use8BitEncoding: use8BitEncoding,
),
);
}