decodeText method
Decodes the given part text with the given codec.
isHeader is set to the true when this text originates from a header
Implementation
@override
String decodeText(String part, Encoding codec, {bool isHeader = false}) {
final outputList = decodeData(part);
return codec.decode(outputList);
}