decodeText abstract method
Decodes the given part text with the given codec.
isHeader is set to the true when this text originates from a header
Implementation
String decodeText(
String part,
convert.Encoding codec, {
bool isHeader = false,
});