noop method
Trigger a noop (no operation).
A noop can update the info about the currently selected mailbox and can be used as a keep alive. Also compare idleStart for starting the IMAP IDLE mode on compatible servers.
Implementation
Future<Mailbox?> noop() {
final cmd = Command(
'NOOP',
writeTimeout: defaultWriteTimeout,
responseTimeout: defaultResponseTimeout,
);
return sendCommand<Mailbox?>(cmd, NoopParser(this, _selectedMailbox));
}