uidThreadMessages method
Requests the UIDs of message threads starting on since
using the given method (defaults to ORDEREDSUBJECT)
and charset (defaults to UTF-8).
You can use this method when the server announces the THREAD
capability, in which it also announces the supported methods, e.g.
THREAD=ORDEREDSUBJECT THREAD=REFERENCES.
Specify a responseTimeout when a response is expected
within the given time.
Compare ServerInfo.supportsThreading and
ServerInfo.supportedThreadingMethods.
Implementation
Future<SequenceNode> uidThreadMessages({
required DateTime since,
String method = 'ORDEREDSUBJECT',
String charset = 'UTF-8',
Duration? responseTimeout,
}) =>
threadMessages(
method: method,
charset: charset,
since: since,
threadUids: true,
responseTimeout: responseTimeout,
);