uidThreadMessages method

Future<SequenceNode> uidThreadMessages({
  1. required DateTime since,
  2. String method = 'ORDEREDSUBJECT',
  3. String charset = 'UTF-8',
  4. Duration? responseTimeout,
})

Requests the UIDs of message threads starting on since using the given method (defaults to ORDEREDSUBJECT) and charset (defaults to UTF-8).

You can use this method when the server announces the THREAD capability, in which it also announces the supported methods, e.g. THREAD=ORDEREDSUBJECT THREAD=REFERENCES. Specify a responseTimeout when a response is expected within the given time. Compare ServerInfo.supportsThreading and ServerInfo.supportedThreadingMethods.

Implementation

Future<SequenceNode> uidThreadMessages({
  required DateTime since,
  String method = 'ORDEREDSUBJECT',
  String charset = 'UTF-8',
  Duration? responseTimeout,
}) => threadMessages(
  method: method,
  charset: charset,
  since: since,
  threadUids: true,
  responseTimeout: responseTimeout,
);